Crate device_driver_core

Crate device_driver_core 

Device driver toolkit

crates.io crates.io Documentation matrix

A toolkit to write better device drivers, faster.

Head over to the website to learn about how to use the project to build your own device drivers.

See the readme in root of the repo for more project information.

This is an internal crate, not meant for public usage. If you do use it, pin the version as this crate does not follow semver.

Structs

CompileOptions
GeneralOptions
Metadata
MirOptions
RustCodegenOptions

Enums

CodegenTarget
TimingsMode

Functions

compile